pub enum CharCase {
Lower = 0,
Title = 2,
Upper = 3,
}🔬This is a nightly-only experimental API. (
titlecase #153892)Expand description
The case of a cased character,
as returned by char::case.
Titlecase characters conceptually are composed of an uppercase portion followed by a lowercase portion. The variant discriminants represent this: the most significant bit represents whether the case conceptually starts as uppercase, while the least significant bit represents whether it conceptually ends as uppercase.
Variants
Lower = 0
🔬This is a nightly-only experimental API. (
titlecase #153892)Lowercase. Corresponds to the Lowercase Unicode property.
Title = 2
🔬This is a nightly-only experimental API. (
titlecase #153892)Titlecase. Corresponds to the Titlecase_Letter Unicode general category.
Upper = 3
🔬This is a nightly-only experimental API. (
titlecase #153892)Uppercase. Corresponds to the Uppercase Unicode property.